@@ -70,8 +70,6 @@ class AsyncSessionTestCase(unittest.TestCase):
             self.run_sync(tx.rollback)
         for ctx in dict.values(self.sessions):
             self.run_sync(ctx.__aexit__, None, None, None)
-        if close_loop:
-            self.loop.close()
 
     def execute_query(self, session, q, name='self'):
         """Execute query `q` and return the awaited result."""
