@@ -21,9 +21,6 @@ class TestAsyncSessionTestCase(AsyncSessionTestCase):
 
     def tearDown(self):
         super().tearDown(close_loop=False)
-        try:
-            session = async_session()
-            result = self.execute_query(session, select(Foo))
-            self.assertEqual(len(list(result)), 0)
-        finally:
-            self.loop.close()
+        session = async_session()
+        result = self.execute_query(session, select(Foo))
+        self.assertEqual(len(list(result)), 0)
